

## Installation


Terminal
======

Build status
------------
|travis status| |appveyor status| |circleci status| |coverage| |quantified code| |scrutinizer|

Project information
-------------------
|license| |pypi version| |gitter|

.. |travis status| image:: https://img.shields.io/travis/spyder-ide/spyder-terminal/master.svg
:target: https://travis-ci.org/spyder-ide/spyder-terminal
:alt: Travis-CI build status
.. |appveyor status| image:: https://img.shields.io/appveyor/ci/spyder-ide/spyder-terminal/master.svg
:target: https://ci.appveyor.com/project/spyder-ide/spyder-terminal
:alt: Appveyor build status
.. |circleci status| image:: https://img.shields.io/circleci/project/github/spyder-ide/spyder-terminal/master.svg
:target: https://circleci.com/gh/spyder-ide/spyder-terminal/tree/master
:alt: Circle-CI build status
.. |quantified code| image:: https://www.quantifiedcode.com/api/v1/project/PROJECT_ID/badge.svg
:target: https://www.quantifiedcode.com/app/project/PROJECT_ID
:alt: Quantified Code issues
.. |scrutinizer| image:: https://img.shields.io/scrutinizer/g/spyder-ide/spyder-terminal.svg
:target: https://scrutinizer-ci.com/g/spyder-ide/spyder-terminal/?branch=master
:alt: Scrutinizer Code Quality
.. |license| image:: https://img.shields.io/pypi/l/spyder-terminal.svg
:target: LICENSE.txt
:alt: License
.. |pypi version| image:: https://img.shields.io/pypi/v/spyder-terminal.svg
:target: https://pypi.python.org/pypi/spyder-terminal
:alt: Latest PyPI version
.. |gitter| image:: https://badges.gitter.im/spyder-ide/spyder-terminal.svg
:target: https://gitter.im/spyder-ide/spyder-terminal
:alt: Join the chat at https://gitter.im/spyder-ide/spyder-terminal
.. |coverage| image:: https://coveralls.io/repos/github/spyder-ide/spyder-terminal/badge.svg
:target: https://coveralls.io/github/spyder-ide/spyder-terminal?branch=master
:alt: Code Coverage


Description
-----------
Spyder Plugin for displaying a virtual terminal (OS independent) inside the main Spyder window.
This plugin allows you to execute flawlessly any bash command inside spyder, even ncurses applications like ``nano`` or ``vi``.

Installation
------------

Using pip

::

pip install spyder_terminal

Using conda

::

conda install spyder_terminal -c spyder-ide

Usage
-----

